@@ -26,6 +26,34 @@ class TrtcClient(AbstractClient):
     _service = 'trtc'
 
 
+    def CreatePicture(self, request):
+        """此接口已废弃，调用将报错。如需使用相关功能请参见 [控制台指南 > 应用管理 > 素材管理](https://cloud.tencent.com/document/product/647/50769)  。
+
+        :param request: Request instance for CreatePicture.
+        :type request: :class:`tencentcloud.trtc.v20190722.models.CreatePictureRequest`
+        :rtype: :class:`tencentcloud.trtc.v20190722.models.CreatePictureResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CreatePicture", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreatePictureResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateTroubleInfo(self, request):
         """创建异常信息
 
@@ -54,6 +82,34 @@ class TrtcClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DeletePicture(self, request):
+        """此接口已废弃，调用将报错。如需使用相关功能请参见 [控制台指南 > 应用管理 > 素材管理](https://cloud.tencent.com/document/product/647/50769)  。
+
+        :param request: Request instance for DeletePicture.
+        :type request: :class:`tencentcloud.trtc.v20190722.models.DeletePictureRequest`
+        :rtype: :class:`tencentcloud.trtc.v20190722.models.DeletePictureResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DeletePicture", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DeletePictureResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeAbnormalEvent(self, request):
         """查询SDKAppID下用户的异常体验事件，返回异常体验ID与可能产生异常体验的原因。可查询15天内数据，查询起止时间不超过1个小时。支持跨天查询。异常体验ID映射见：https://cloud.tencent.com/document/product/647/44916
 
@@ -167,6 +223,34 @@ class TrtcClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribePicture(self, request):
+        """此接口已废弃，调用将报错。如需使用相关功能请参见 [控制台指南 > 应用管理 > 素材管理](https://cloud.tencent.com/document/product/647/50769)  。
+
+        :param request: Request instance for DescribePicture.
+        :type request: :class:`tencentcloud.trtc.v20190722.models.DescribePictureRequest`
+        :rtype: :class:`tencentcloud.trtc.v20190722.models.DescribePictureResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribePicture", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribePictureResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeRealtimeNetwork(self, request):
         """查询sdkappid维度下每分钟实时网络状态，包括上行丢包与下行丢包。可查询24小时内数据，查询起止时间不低于1分钟，不超过1个小时。
 
@@ -462,6 +546,34 @@ class TrtcClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ModifyPicture(self, request):
+        """此接口已废弃，调用将报错。如需使用相关功能请参见 [控制台指南 > 应用管理 > 素材管理](https://cloud.tencent.com/document/product/647/50769)  。
+
+        :param request: Request instance for ModifyPicture.
+        :type request: :class:`tencentcloud.trtc.v20190722.models.ModifyPictureRequest`
+        :rtype: :class:`tencentcloud.trtc.v20190722.models.ModifyPictureResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ModifyPicture", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ModifyPictureResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def RemoveUser(self, request):
         """接口说明：将用户从房间移出，适用于主播/房主/管理员踢人等场景。支持所有平台，Android、iOS、Windows 和 macOS 需升级到 TRTC SDK 6.6及以上版本。
 
